"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bodyParser = require("body-parser");
const compression = require("compression");
const cookieParser = require("cookie-parser");
const session = require("cookie-session");
const express = require("express");
const Path = require("path");
const CloudExplorerRouter_1 = require("./router/CloudExplorerRouter");
const PublishRouter_1 = require("./router/PublishRouter");
const SslRouter_1 = require("./router/SslRouter");
const StaticRouter_1 = require("./router/StaticRouter");
const WebsiteRouter_1 = require("./router/WebsiteRouter");
function noCache(req, res, next) {
    res.header('Cache-Control', 'private,no-cache,no-store,must-revalidate,proxy-revalidate');
    res.header('Expires', '-1');
    res.header('Pragma', 'no-cache');
    next();
}
function withCache(req, res, next) {
    res.header('Cache-Control', 'public,max-age=86400,immutable');
    next();
}
function SilexServer(config) {
    if (config.serverOptions.debug) {
        require('source-map-support').install();
    }
    this.config = config;
    this.app = express();
    this.app.use(compression());
    this.app.use(bodyParser.json({ limit: '1mb' }));
    this.app.use(bodyParser.text({ limit: '10mb' }));
    this.app.use(cookieParser());
    this.app.use(session({
        name: 'silex-session',
        secret: this.config.serverOptions.sessionSecret,
    }));
    this.staticRouter = StaticRouter_1.default(this.config.staticOptions);
    this.ceRouter = CloudExplorerRouter_1.default(this.config.ceOptions);
    this.websiteRouter = WebsiteRouter_1.default(this.config.serverOptions, this.ceRouter.unifile);
    this.publishRouter = PublishRouter_1.default(this.config.publisherOptions, this.ceRouter.unifile);
    this.sslRouter = SslRouter_1.default(this.config.sslOptions, this.app);
    this.unifile = this.ceRouter.unifile;
}
exports.default = SilexServer;
SilexServer.prototype.start = function (cbk) {
    this.app.use(this.config.serverOptions.cePath, this.ceRouter);
    this.app.use(withCache, this.staticRouter);
    this.app.use(noCache, this.websiteRouter);
    this.app.use(noCache, this.publishRouter);
    this.app.use(this.sslRouter);
    if (this.config.electronOptions.enabled) {
        require(Path.join(__dirname, 'silex_electron'));
    }
    this.app.listen(this.config.serverOptions.port, () => {
        console.info(`\nI'm ready, listening to port ${this.config.serverOptions.port}\n`);
        if (cbk) {
            cbk();
        }
    });
};
