"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Path = require("path");
const url_1 = require("url");
const Constants_1 = require("../../Constants");
const DomTools_1 = require("../utils/DomTools");
class DomPublisher {
    constructor(dom, userHead, rootUrl, rootPath, getDestFolder) {
        this.dom = dom;
        this.userHead = userHead;
        this.rootUrl = rootUrl;
        this.rootPath = rootPath;
        this.getDestFolder = getDestFolder;
        this.doc = dom.window.document;
    }
    cleanupFirefoxInlines() {
        ['script', 'style'].forEach((tagName) => {
            Array.from(this.doc.querySelectorAll(`${tagName}[style="display:none"]`))
                .forEach((element) => {
                element.parentElement.removeChild(element);
            });
        });
    }
    cleanup() {
        Array.from(this.doc.querySelectorAll(Constants_1.Constants.ELEMENTS_TO_REMOVE_AT_PUBLISH.join(', ')))
            .forEach((tagToRemove) => {
            tagToRemove.parentElement.removeChild(tagToRemove);
        });
        Array.from(this.doc.querySelectorAll(`[${Constants_1.Constants.TYPE_ATTR}], [${Constants_1.Constants.ELEMENT_ID_ATTR_NAME}], [${Constants_1.Constants.STATIC_ASSET_ATTR}]`))
            .forEach((tagToClean) => {
            tagToClean.removeAttribute(Constants_1.Constants.ELEMENT_ID_ATTR_NAME);
            tagToClean.removeAttribute(Constants_1.Constants.STATIC_ASSET_ATTR);
            tagToClean.removeAttribute('data-dependency');
        });
    }
    split(newFirstPageName) {
        this.doc.body.classList.add(Constants_1.Constants.WEBSITE_CONTEXT_PUBLISHED_CLASS_NAME);
        ['js/jquery-ui.js', 'js/pageable.js']
            .map((path) => this.doc.querySelector(`script[src="${path}"]`))
            .filter((el) => !!el)
            .forEach((el) => el.parentElement.removeChild(el));
        const pages = Array.from(this.doc.querySelectorAll(`a[${Constants_1.Constants.TYPE_ATTR}="${Constants_1.Constants.TYPE_PAGE}"]`));
        const initialFirstPageName = pages[0].getAttribute('id');
        return pages
            .map((el, idx) => {
            return {
                name: el.getAttribute('id'),
                displayName: el.innerHTML,
                fileName: el.getAttribute('id') === initialFirstPageName && newFirstPageName ? 'index.html' : (el.getAttribute('id').substr('page-'.length) + '.html'),
            };
        })
            .map(({ displayName, name, fileName }) => {
            const clone = this.doc.cloneNode(true);
            (clone.head.querySelector('title') || {}).innerHTML += ' - ' + displayName;
            Array.from(clone.querySelectorAll(`.${Constants_1.Constants.PAGED_CLASS_NAME}`))
                .forEach((el) => {
                if (el.classList.contains(name)) {
                    el.classList.add('page-link-active');
                }
                else {
                    el.parentElement.removeChild(el);
                }
            });
            Array.from(clone.querySelectorAll('a'))
                .filter((el) => el.hash.startsWith('#!'))
                .forEach((el) => {
                const [pageName, anchor] = el.hash.substr('#!'.length).split('#');
                el.href = (pageName === initialFirstPageName && newFirstPageName ? 'index.html' : pageName.substr('page-'.length) + '.html') + (anchor ? '#' + anchor : '');
                if (pageName === name) {
                    el.classList.add('page-link-active');
                }
                else {
                    el.classList.remove('page-link-active');
                }
            });
            Constants_1.Constants.SILEX_CLASS_NAMES_TO_REMOVE_AT_PUBLISH.forEach((className) => {
                Array.from(clone.getElementsByClassName(className))
                    .forEach((el) => el.classList.remove(className));
            });
            return {
                name: 'writefile',
                path: this.rootPath + '/' + this.getDestFolder('.html', null) + '/' + fileName,
                displayName: fileName,
                content: '<!doctype html>' + clone.documentElement.outerHTML,
            };
        });
    }
    extractAssets(baseUrl) {
        const files = [];
        DomTools_1.default.transformPaths(this.dom, (path, el, isInHead) => {
            const tagName = el ? el.tagName : null;
            const url = new url_1.URL(path, baseUrl);
            if (this.isDownloadable(url)) {
                const fileName = Path.basename(url.pathname);
                const destFolder = this.getDestFolder(Path.extname(url.pathname), tagName);
                if (destFolder) {
                    const destPath = `${destFolder}/${fileName}`;
                    files.push({
                        original: path,
                        srcPath: url.href,
                        destPath: this.rootPath + '/' + destPath,
                        tagName,
                        displayName: fileName,
                    });
                    if (tagName) {
                        return destPath;
                    }
                    else if (isInHead) {
                        return '../' + destPath;
                    }
                    return destPath;
                }
            }
            return null;
        });
        const scriptTags = [];
        Array.from(this.doc.head.querySelectorAll('script'))
            .forEach((tag) => {
            if (!tag.src && tag.innerHTML) {
                tag.parentElement.removeChild(tag);
                scriptTags.push(tag);
            }
        });
        if (scriptTags.length > 0) {
            const scriptTagSrc = this.doc.createElement('script');
            scriptTagSrc.src = 'js/script.js';
            scriptTagSrc.type = 'text/javascript';
            this.doc.head.appendChild(scriptTagSrc);
        }
        else {
            console.info('no script found in head');
        }
        const styleTags = [];
        Array.from(this.doc.head.querySelectorAll('style'))
            .forEach((tag) => {
            tag.parentElement.removeChild(tag);
            styleTags.push(tag);
        });
        if (styleTags.length > 0) {
            const cssTagSrc = this.doc.createElement('link');
            cssTagSrc.href = 'css/styles.css';
            cssTagSrc.rel = 'stylesheet';
            cssTagSrc.type = 'text/css';
            this.doc.head.appendChild(cssTagSrc);
        }
        else {
            console.warn('no styles found in head');
        }
        this.doc.head.innerHTML += this.userHead;
        const links = Array.from(this.doc.body.querySelectorAll(`.${Constants_1.Constants.EDITABLE_CLASS_NAME}[${Constants_1.Constants.LINK_ATTR}]`))
            .forEach((element) => {
            const href = element.getAttribute(Constants_1.Constants.LINK_ATTR);
            element.removeAttribute(Constants_1.Constants.LINK_ATTR);
            const replacement = this.doc.createElement('a');
            replacement.setAttribute('href', href);
            replacement.innerHTML = element.innerHTML;
            for (let attrIdx = 0; attrIdx < element.attributes.length; attrIdx++) {
                const nodeName = element.attributes.item(attrIdx).nodeName;
                const nodeValue = element.attributes.item(attrIdx).nodeValue;
                replacement.setAttribute(nodeName, nodeValue);
            }
            element.parentElement.replaceChild(replacement, element);
        });
        return {
            scriptTags,
            styleTags,
            files,
        };
    }
    isDownloadable(url) {
        return url.search === ''
            && url.protocol !== 'data:'
            && url.origin === this.rootUrl;
    }
}
exports.DomPublisher = DomPublisher;
