"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const HostingGhPages_1 = require("../hosting-provider/HostingGhPages");
const HostingJekyll_1 = require("../hosting-provider/HostingJekyll");
const HostingUnifile_1 = require("../hosting-provider/HostingUnifile");
const PublishJob_1 = require("../publication/PublishJob");
const hostingProviders = [];
const router = express.Router();
function PublishRouter({ port, rootUrl, enableHostingGhPages, enableHostingUnifile, enableHostingJekyll, skipHostingSelection }, unifile) {
    if (enableHostingUnifile) {
        const hostingUnifile = new HostingUnifile_1.default(unifile);
        addHostingProvider(hostingUnifile);
    }
    if (enableHostingGhPages) {
        const hostingGhPages = new HostingGhPages_1.default(unifile);
        addHostingProvider(hostingGhPages);
    }
    if (enableHostingJekyll) {
        const hostingJekyll = new HostingJekyll_1.default(unifile);
        addHostingProvider(hostingJekyll);
    }
    router.post('/tasks/publish', (req, res, next) => {
        if (!req.body.provider || !req.body.provider.name) {
            res.status(400).send({
                message: 'Error in the request, hosting provider required',
            });
        }
        else {
            PublishJob_1.default.create(req.body, unifile, req.session, req.cookies, rootUrl, getHostingProvider(req.session.unifile, req.body.provider.name));
            res.end();
        }
    });
    router.get('/tasks/publishState', (req, res, next) => {
        const publishJob = PublishJob_1.default.get(req.session.publicationId);
        if (publishJob) {
            if (publishJob.error) {
                res.status(500);
            }
            res.send({
                message: publishJob.getStatus(),
                stop: publishJob.isStopped(),
            });
        }
        else {
            res.status(404).send({
                message: 'No pending publication.',
                stop: true,
            });
        }
    });
    router.get('/hosting/', (req, res, next) => {
        const session = !!req.session && !!req.session.unifile ? req.session.unifile : {};
        res.json({
            providers: hostingProviders.map((hostingProvider) => hostingProvider.getOptions(session)),
            skipHostingSelection,
        });
    });
    router.get('/hosting/:hostingProviderName/vhost', (req, res, next) => {
        const hostingProvider = getHostingProviderFromReq(req);
        const hostingProviderInfo = hostingProvider.getOptions(req.session.unifile);
        hostingProvider.getVhosts(req.session.unifile)
            .then((vhosts) => {
            res.json(vhosts);
        })
            .catch((err) => {
            res.status(400).send({
                message: `Error from hosting provider "${hostingProviderInfo.displayName}": ${err.message}`,
                err,
            });
        });
    });
    router.get('/hosting/:hostingProviderName/vhost/:name', (req, res, next) => {
        const hostingProvider = getHostingProviderFromReq(req);
        hostingProvider.getVhostData(req.session.unifile, req.params.name)
            .then((result) => {
            res.json(result);
        })
            .catch((err) => {
            res.json({
                domain: '',
                msg: err,
            });
        });
    });
    router.post('/hosting/:hostingProviderName/vhost/:name', (req, res, next) => {
        const hostingProvider = getHostingProviderFromReq(req);
        const data = {
            domain: req.body.domain,
        };
        hostingProvider.setVhostData(req.session.unifile, req.params.name, data)
            .then((result) => {
            res.json(result);
        })
            .catch((err) => {
            console.error('Error when trying to attach a domain', req.params.name, data, err);
            res.status(400).send({
                message: `Error when trying to attach a domain to "${req.params.name}". Error details: ${err.message}`,
                err,
            });
        });
    });
    router.delete('/hosting/:hostingProviderName/vhost/:name', (req, res, next) => {
        const hostingProvider = getHostingProviderFromReq(req);
        hostingProvider.setVhostData(req.session.unifile, req.params.name, null)
            .then((result) => {
            res.json(result);
        })
            .catch((err) => {
            console.error('Error when trying to delete a domain', req.params.name, err);
            res.status(400).send({
                message: `Error when trying to remove domain from "${req.params.name}". Error details: ${err.message}`,
                err,
            });
        });
    });
    router.addHostingProvider = (hostingProvider) => addHostingProvider(hostingProvider);
    return router;
}
exports.default = PublishRouter;
function addHostingProvider(hostingProvider) {
    console.log('> Adding hosting provider', hostingProvider.getOptions({}).displayName);
    hostingProviders.push(hostingProvider);
}
function getHostingProviderFromReq(req) {
    const hostingProviderName = req.params.hostingProviderName;
    const hostingProvider = getHostingProvider(req.session.unifile, hostingProviderName);
    if (!hostingProvider) {
        throw new Error(('Could not find the hosting provider ' + hostingProviderName));
    }
    return hostingProvider;
}
function getHostingProvider(session, hostingProviderName) {
    return hostingProviders.find((hostingProvider) => hostingProvider.getOptions(session).name === hostingProviderName);
}
