"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cloud_explorer_1 = require("cloud-explorer");
const express = require("express");
const fs = require("fs");
const jsdom_1 = require("jsdom");
const nodeModules = require("node_modules-path");
const Path = require("path");
const url_1 = require("url");
const Constants_1 = require("../../Constants");
const BackwardCompat_1 = require("../utils/BackwardCompat");
const DomTools_1 = require("../utils/DomTools");
function default_1({ port, rootUrl }, unifile) {
    const backwardCompat = new BackwardCompat_1.default(rootUrl);
    function isInTemplateFolder(path) {
        if (path.startsWith(Path.join(nodeModules('silex-templates'), 'silex-templates')) ||
            path.startsWith(Path.join(nodeModules('silex-blank-templates'), 'silex-blank-templates'))) {
            return true;
        }
        return false;
    }
    function getTemplatesList(req, res, next) {
        const templateFolder = Path.join(nodeModules(req.params.folder), req.params.folder);
        if (!isInTemplateFolder(templateFolder)) {
            console.error('Error while trying to get the json representation of the folder ', templateFolder);
            res.send({ success: false, error: 'Error while trying to get the json representation of the folder ' + req.params.folder + ' - folder does not exist' });
            return;
        }
        fs.readdir(templateFolder, (err, result) => {
            if (err) {
                console.error('Error while trying to get the json representation of the folder ', templateFolder, err);
                res.send({ success: false, error: 'Error while trying to get the json representation of the folder ' + req.params.folder + ' - ' + err });
            }
            else {
                const templateList = result.filter((entry) => {
                    return fs.statSync(Path.join(templateFolder, entry)).isDirectory();
                });
                res.send(templateList);
            }
        });
    }
    function readWebsite(req, res, next) {
        const connector = req.params[0];
        const path = req.params[1];
        const url = new url_1.URL(`${rootUrl}/ce/${connector}/get/${Path.dirname(path)}/`);
        unifile.readFile(req.session.unifile, connector, path)
            .then((buffer) => {
            return sendWebsiteData(res, buffer, url);
        })
            .catch((err) => {
            console.error('unifile error catched:', err);
            cloud_explorer_1.default.handleError(res, err);
        });
    }
    function readTemplate(req, res, next) {
        const path = req.params[0];
        const localPath = Path.resolve(nodeModules('silex-templates'), path);
        const url = new url_1.URL(`${rootUrl}/libs/templates/${Path.dirname(path)}/`);
        if (isInTemplateFolder(localPath)) {
            fs.readFile(localPath, (err, buffer) => {
                if (err) {
                    cloud_explorer_1.default.handleError(res, err);
                }
                else {
                    sendWebsiteData(res, buffer, url);
                }
            });
        }
        else {
            cloud_explorer_1.default.handleError(res, { message: 'Not authorized.', code: 'EACCES' });
        }
    }
    function sendWebsiteData(res, buffer, url) {
        const { html, userHead } = DomTools_1.default.extractUserHeadTag(buffer.toString('utf-8'));
        const dom = new jsdom_1.JSDOM(html, { url: url.href });
        return backwardCompat.update(dom.window.document)
            .then((wanrningMsg) => {
            prepareWebsite(dom, url);
            const str = dom.serialize();
            dom.window.close();
            res.send({
                message: wanrningMsg,
                html: str,
                userHead,
            });
        })
            .catch((err) => {
            console.error('Could not send website data: ', err);
            res.status(400).send({
                message: err.message,
            });
        });
    }
    function writeWebsite(req, res, next) {
        const connector = req.params[0];
        const path = req.params[1];
        const { userHead, html } = JSON.parse(req.body);
        const url = new url_1.URL(`${rootUrl}/ce/${connector}/get/${Path.dirname(path)}/`);
        const dom = new jsdom_1.JSDOM(html, { url: url.href });
        unprepareWebsite(dom, url);
        const str = dom.serialize();
        const fullHtml = DomTools_1.default.insertUserHeadTag(str, userHead);
        dom.window.close();
        unifile.writeFile(req.session.unifile, connector, req.params[1], fullHtml)
            .then((result) => {
            res.send(result);
        })
            .catch((err) => {
            console.error('unifile error catched:', err);
            cloud_explorer_1.default.handleError(res, err);
        });
    }
    function prepareWebsite(dom, baseUrl) {
        DomTools_1.default.transformPaths(dom, (path, el) => {
            const url = new url_1.URL(path, baseUrl);
            return url.href;
        });
        dom.window.document.body.classList.remove(Constants_1.Constants.WEBSITE_CONTEXT_RUNTIME_CLASS_NAME);
        dom.window.document.body.classList.add(Constants_1.Constants.WEBSITE_CONTEXT_EDITOR_CLASS_NAME);
        deactivateScripts(dom);
        const tag = dom.window.document.createElement('link');
        tag.rel = 'stylesheet';
        tag.href = rootUrl + '/css/editable.css';
        tag.classList.add(Constants_1.Constants.SILEX_TEMP_TAGS_CSS_CLASS);
        dom.window.document.head.appendChild(tag);
    }
    function unprepareWebsite(dom, baseUrl) {
        dom.window.document.body.classList.add(Constants_1.Constants.WEBSITE_CONTEXT_RUNTIME_CLASS_NAME);
        dom.window.document.body.classList.remove(Constants_1.Constants.WEBSITE_CONTEXT_EDITOR_CLASS_NAME);
        reactivateScripts(dom);
        restoreIFrames(dom);
        cleanupNoscripts(dom);
        DomTools_1.default.transformPaths(dom, (path, el) => {
            const url = new url_1.URL(path, baseUrl);
            if (url.href.startsWith(rootUrl)) {
                return Path.relative(baseUrl.pathname, url.pathname);
            }
            return path;
        });
        Array.from(dom.window.document.querySelectorAll(`
      .${Constants_1.Constants.SILEX_TEMP_TAGS_CSS_CLASS},
      #${Constants_1.Constants.SILEX_CURRENT_PAGE_ID},
      .${Constants_1.Constants.RISZE_HANDLE_CSS_CLASS}`))
            .forEach((el) => {
            el.remove();
        });
        Constants_1.Constants.SILEX_TEMP_CLASS_NAMES.forEach((className) => {
            Array.from(dom.window.document.getElementsByClassName(className))
                .forEach((el) => el.classList.remove(className));
        });
        dom.window.document.body.style.minWidth = '';
        dom.window.document.body.style.minHeight = '';
        dom.window.document.body.style.overflow = '';
    }
    function deactivateScripts(dom) {
        Array.from(dom.window.document.getElementsByTagName('script'))
            .forEach((el) => {
            if (!el.hasAttribute('data-silex-static') && (!el.hasAttribute('type') || el.getAttribute('type') === 'text/javascript')) {
                el.setAttribute('type', 'text/notjavascript');
            }
        });
    }
    function restoreIFrames(dom) {
        Array.from(dom.window.document.querySelectorAll('[data-silex-iframe-src]'))
            .forEach((el) => {
            el.setAttribute('src', el.getAttribute('data-silex-iframe-src'));
            el.removeAttribute('data-silex-iframe-src');
        });
    }
    function cleanupNoscripts(dom) {
        Array.from(dom.window.document.querySelectorAll('noscript'))
            .forEach((el) => {
            el.innerHTML = decodeHTMLEntities(el.innerHTML);
        });
    }
    function decodeHTMLEntities(text) {
        const entities = [['amp', '&'], ['apos', '\''], ['#x27', '\''], ['#x2F', '/'], ['#39', '\''], ['#47', '/'], ['lt', '<'], ['gt', '>'], ['nbsp', ' '], ['quot', '"']];
        entities.forEach((entity) => text = text.replace(new RegExp('&' + entity[0] + ';', 'g'), entity[1]));
        return text;
    }
    function reactivateScripts(dom) {
        Array.from(dom.window.document.querySelectorAll('script[type="text/notjavascript"]'))
            .forEach((el) => el.setAttribute('type', 'text/javascript'));
    }
    const router = express.Router();
    router.get(/\/website\/ce\/(.*)\/get\/(.*)/, readWebsite);
    router.get(/\/website\/libs\/templates\/(.*)/, readTemplate);
    router.put(/\/website\/ce\/(.*)\/put\/(.*)/, writeWebsite);
    router.use('/get/:folder', getTemplatesList);
    return router;
}
exports.default = default_1;
